pub fn reserve_aligned(size: usize, align: usize) -> Option<Reservation>Expand description
Reserve size bytes of anonymous virtual memory whose base is aligned to
align, via the over-reserve + trim technique.
Returns None on a contract violation or if the OS refuses the reservation
(OOM) — never panics, so it is safe to call from inside a GlobalAlloc
implementation.